==> nodegit-0.2.4.tgz: package/src/cred_default.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/cred_default.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitCredDefault::GitCredDefault(git_cred_default *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitCredDefault::~GitCredDefault() {
   }

  void GitCredDefault::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(New);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("CredDefault"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("CredDefault"), _constructor_template);
  }

  NAN_METHOD(GitCredDefault::New) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitCredDefault cannot be instantiated.");
     }

    GitCredDefault* object = new GitCredDefault(static_cast<git_cred_default *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitCredDefault::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitCredDefault::constructor_template)->NewInstance(2, argv));
  }

  git_cred_default *GitCredDefault::GetValue() {
    return this->raw;
  }

  git_cred_default **GitCredDefault::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitCredDefault::constructor_template;

==> nodegit-0.2.5.tgz: package/src/cred_default.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/cred_default.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitCredDefault::GitCredDefault(git_cred_default *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitCredDefault::~GitCredDefault() {
   }

  void GitCredDefault::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(JSNewFunction);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("CredDefault"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("CredDefault"), _constructor_template);
  }

  NAN_METHOD(GitCredDefault::JSNewFunction) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitCredDefault cannot be instantiated.");
     }

    GitCredDefault* object = new GitCredDefault(static_cast<git_cred_default *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitCredDefault::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitCredDefault::constructor_template)->NewInstance(2, argv));
  }

  git_cred_default *GitCredDefault::GetValue() {
    return this->raw;
  }

  git_cred_default **GitCredDefault::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitCredDefault::constructor_template;
